@@ -13,12 +13,10 @@ from backports.configparser import (
     ConfigParser,
     SafeConfigParser,
     SectionProxy,
-
     Interpolation,
     BasicInterpolation,
     ExtendedInterpolation,
     LegacyInterpolation,
-
     NoSectionError,
     DuplicateSectionError,
     DuplicateOptionError,
@@ -30,25 +28,34 @@ from backports.configparser import (
     ParsingError,
     MissingSectionHeaderError,
     ConverterMapping,
-
     DEFAULTSECT,
     MAX_INTERPOLATION_DEPTH,
 )
 
-from backports.configparser import (  # noqa: F401
-    Error,
-    _UNSET,
-    _default_dict,
-    _ChainMap,
-)
+from backports.configparser import Error, _UNSET, _default_dict, _ChainMap  # noqa: F401
 
-__all__ = ["NoSectionError", "DuplicateOptionError", "DuplicateSectionError",
-           "NoOptionError", "InterpolationError", "InterpolationDepthError",
-           "InterpolationMissingOptionError", "InterpolationSyntaxError",
-           "ParsingError", "MissingSectionHeaderError",
-           "ConfigParser", "SafeConfigParser", "RawConfigParser",
-           "Interpolation", "BasicInterpolation", "ExtendedInterpolation",
-           "LegacyInterpolation", "SectionProxy", "ConverterMapping",
-           "DEFAULTSECT", "MAX_INTERPOLATION_DEPTH"]
+__all__ = [
+    "NoSectionError",
+    "DuplicateOptionError",
+    "DuplicateSectionError",
+    "NoOptionError",
+    "InterpolationError",
+    "InterpolationDepthError",
+    "InterpolationMissingOptionError",
+    "InterpolationSyntaxError",
+    "ParsingError",
+    "MissingSectionHeaderError",
+    "ConfigParser",
+    "SafeConfigParser",
+    "RawConfigParser",
+    "Interpolation",
+    "BasicInterpolation",
+    "ExtendedInterpolation",
+    "LegacyInterpolation",
+    "SectionProxy",
+    "ConverterMapping",
+    "DEFAULTSECT",
+    "MAX_INTERPOLATION_DEPTH",
+]
 
 # NOTE: names missing from __all__ imported anyway for backwards compatibility.
